@@ -25,11 +25,8 @@ impl Land {
     /// assert_eq!(land.tp, Type::Empty);
     /// assert_eq!(land.amount, 0);
     /// ```
+    #[inline]
     pub fn new() -> Self {
-        Self {
-            color: Color::Grey,
-            tp: Type::Empty,
-            amount: 0,
-        }
+        Self::default()
     }
 }
