@@ -4,6 +4,8 @@
 
 pub mod error;
 pub mod land;
+pub mod map;
 
 pub use error::*;
 pub use land::*;
+pub use map::*;
